
.onAttach <- function(libname, pkgname) {
  packageStartupMessage("   O      ")
  packageStartupMessage("  / \\     ")
  packageStartupMessage(" F   O  ")
  packageStartupMessage("    / \\   ")
  packageStartupMessage("   F   T  ")
  packageStartupMessage("FFTrees v1.3.4. Email: Nathaniel.D.Phillips.is@gmail.com")
  packageStartupMessage("FFTrees.guide() opens the package guide. Citation info at citation('FFTrees')")
}
